@@ -1,6 +1,8 @@
 
 
-check_sentence_ending_periods <- function(filename, .report_error){
+check_sentence_ending_periods <- function(filename,
+                                          .report_error,
+                                          ignore_hl = TRUE) {
   if (missing(.report_error)){
     .report_error <- function(...) report2console(...)
   }
@@ -10,6 +12,15 @@ check_sentence_ending_periods <- function(filename, .report_error){
     gsub("((?<!(\\\\))%).*$", "", ., perl = TRUE) %>%
     stri_trim_both
   
+  if (ignore_hl) {
+    hl_lines <- grep("\\hl{", lines, fixed = TRUE)
+    if (length(hl_lines)) {
+      lines[hl_lines] <- 
+        gsub("\\\\hl\\{[^\\}]++\\}", "", lines[hl_lines],
+             perl = TRUE)
+    }
+  }
+  
   if (any(grepl("[A-Z]\\.\\s+[A-Z]", lines, perl = TRUE)) || 
       any(and(lag(grepl("[A-Z]\\.$", lines, perl = TRUE)),
               grepl("^[A-Z]", lines, perl = TRUE)))){
